Enum hyper::header::DispositionParam [−] [src]

pub enum DispositionParam {
    Filename(Charset, Option<LanguageTag>, Vec<u8>),
    Ext(String, String),
}

A parameter to the disposition type

Variants

Filename(Charset, Option<LanguageTag>, Vec<u8>)

A Filename consisting of a Charset, an optional LanguageTag, and finally a sequence of bytes representing the filename

Ext(String, String)

Extension type consisting of token and value. Recipients should ignore unrecognized parameters.